summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoToolBox.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficeui/KoToolBox.h')
-rw-r--r--lib/kofficeui/KoToolBox.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/lib/kofficeui/KoToolBox.h b/lib/kofficeui/KoToolBox.h
index 25c9f1c4..93a82b34 100644
--- a/lib/kofficeui/KoToolBox.h
+++ b/lib/kofficeui/KoToolBox.h
@@ -26,15 +26,15 @@
#include <ktoolbar.h>
class TQWidget;
-class KAction;
-class KMainWindow;
+class TDEAction;
+class TDEMainWindow;
class KDualColorButton;
class TQGridLayout;
class ToolArea;
/**
* KActionBox is a kind of super-specialized toolbox that can order
* tools according to type and priority.
*
* This is to a large extent a port of the Karbon vtoolbox -- with
@@ -42,21 +42,21 @@ class ToolArea;
* tool-like class, it aggregates actions.
*/
-class KOFFICEUI_EXPORT KoToolBox : public KToolBar {
+class KOFFICEUI_EXPORT KoToolBox : public TDEToolBar {
Q_OBJECT
public:
- KoToolBox( KMainWindow *mainWin, const char* name, TDEInstance* instance, int numberOfTooltypes);
+ KoToolBox( TDEMainWindow *mainWin, const char* name, TDEInstance* instance, int numberOfTooltypes);
virtual ~KoToolBox();
// Called by the toolcontroller for each tool. For every category,
// there is a separate list, and the tool is categorized correctly.
// The tool is not yet added to the widgets; call setupTools()
// to do that. We don't store the tool.
- void registerTool(KAction * tool, int toolType, TQ_UINT32 priority);
+ void registerTool(TDEAction * tool, int toolType, TQ_UINT32 priority);
// Called when all tools have been added by the tool controller
void setupTools();
@@ -84,10 +84,10 @@ private:
TQPtrList<ToolArea> m_toolBoxes; // For every ToolArea
- typedef TQMap< int, KAction*> ToolList; // The priority ordered list of tools for a certain tooltype
+ typedef TQMap< int, TDEAction*> ToolList; // The priority ordered list of tools for a certain tooltype
TQPtrList<ToolList> m_tools;
- TQPtrList<KAction> m_idToActionMap; // Map the buttongroup id's to actions for easy activating.
+ TQPtrList<TDEAction> m_idToActionMap; // Map the buttongroup id's to actions for easy activating.
TDEInstance* m_instance;
};
@@ -26,15 +26,15 @@
class ToolArea;
/**
- * KActionBox is a kind of super-specialized toolbox that can order
+ * TDEActionBox is a kind of super-specialized toolbox that can order
* tools according to type and priority.
*